summaryrefslogtreecommitdiffstats
path: root/kmail/searchwindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/searchwindow.h')
-rw-r--r--kmail/searchwindow.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kmail/searchwindow.h b/kmail/searchwindow.h
index c3c8cf85..f8da35d7 100644
--- a/kmail/searchwindow.h
+++ b/kmail/searchwindow.h
@@ -68,17 +68,18 @@ namespace KMail {
class SearchWindow: public KDialogBase, virtual public KXMLGUIClient
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Creates a new search window.
* @param parent The parent widget.
* @param name The (widget) name of the dialog.
* @param curFolder The folder which will be pre-selected as the base folder
* of search operations.
* @param modal Whether the dialog is to be shown modal.
*/
- SearchWindow( KMMainWidget* parent, const char* name=0,
+ SearchWindow( KMMainWidget* tqparent, const char* name=0,
KMFolder *curFolder=0, bool modal=false );
virtual ~SearchWindow();
@@ -104,7 +105,7 @@ public:
protected slots:
/** Update status line widget. */
- virtual void updStatus(void);
+ virtual void updtqStatus(void);
virtual void slotClose();
virtual void slotSearch();
@@ -161,7 +162,7 @@ protected:
TQGuardedPtr<KMFolderSearch> mFolder;
TQTimer *mTimer;
- // GC'd by Qt
+ // GC'd by TQt
TQRadioButton *mChkbxAllFolders;
TQRadioButton *mChkbxSpecificFolders;
KMail::FolderRequester *mCbxFolders;
@@ -68,17 +68,18 @@ namespace KMail {
/**
* Creates a new search window.
- * @param parent The parent widget.
+ * @param tqparent The tqparent widget.
* @param name The (widget) name of the dialog.
* @param curFolder The folder which will be pre-selected as the base folder